// Sample dataset
const salesData = [
  { month: 'January', sales: 150 },
  { month: 'February', sales: 200 },
  { month: 'March', sales: 120 },
  { month: 'April', sales: 170 },
  { month: 'May', sales: 160 },
  { month: 'June', sales: 180 },
];

// Select the SVG element
const svg = d3.select('svg');
const margin = { top: 20, right: 30, bottom: 30, left: 50 };
const width =
  svg.attr('width') - margin.left - margin.right;
const height =
  svg.attr('height') - margin.top - margin.bottom;
const g = svg
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Scales
const x = d3
  .scaleBand()
  .domain(salesData.map((d) => d.month))
  .rangeRound([0, width])
  .padding(0.1);

const y = d3
  .scaleLinear()
  .domain([0, d3.max(salesData, (d) => d.sales)])
  .rangeRound([height, 0]);

// Area generator
const area = d3
  .area()
  .x((d) => x(d.month) + x.bandwidth() / 2) // Center the area below the axis tick
  .y0(height)
  .y1((d) => y(d.sales));

// Append the area to the SVG
g.append('path')
  .datum(salesData)
  .attr('fill', 'steelblue')
  .attr('d', area);

// Append the X axis
g.append('g')
  .attr('transform', `translate(0,${height})`)
  .call(d3.axisBottom(x));

// Append the Y axis
g.append('g').call(d3.axisLeft(y));
